//      program name:  exmqget1 - example of MQPUT to write a message to a queue
//                
//                exmqget1 has 2 parameters:
//                - the name of a queue (required)
//                - the name of a queue manager (required)
//
//    example command line:   exmqget1 LEXQ1 EXQMAN

using System;
using IBM.WMQ;

namespace exmqget1
{
  /// <summary>
  /// Summary description for exmqget1.
  /// </summary>
  class exmqget1
  {
    /// <summary>
    /// The main entry point for the application.
    /// </summary>
    [STAThread]
    static void Main(String[] args)
    {
      MQQueueManager      mqQMgr;          // MQQueueManager instance
      MQQueue             mqQueue;         // MQQueue instance
      MQMessage           mqMsg;           // MQMessage instance
      MQGetMessageOptions mqGetMsgOpts;    // MQGetMessageOptions instance
      MQRCText            mqrcText;        // MQRCText instance
      String              queueName;       // Name of queue to use

      System.Console.WriteLine( "Example exmqget1 start" );
      if (args.Length == 0) 
      {
        System.Console.WriteLine("Required parameters missing - 'queue name' 'queue manager name'" );
        return;
      }
      else 
      {
        queueName = args[0];
      }

      ///
      /// create an MQRCText instance
      /// 
       
      mqrcText = new MQRCText();
       
      ///
      /// Try to create an MQQueueManager instance 
      /// 
      try 
      {
        if (args.Length > 1)
        {
          // queue name, queue manager name provided
          mqQMgr = new MQQueueManager( args[1] );
          System.Console.WriteLine( "MQQueueManager: " + mqQMgr );
        }
        else 
        {
          if (args[0] == "?")
          {
           System.Console.WriteLine("execute exmqget1 as follows: exmqget1 'queue name' 'queue manager name'" );
           System.Console.WriteLine("                         eg. exmqget1 LEXQ1 EXQMAN " );
           return;
          }
          else
          {
            System.Console.WriteLine("Required parameter missing - queue manager name" );
            return;
          }
        }
      }
      catch (MQException mqe) 
      {
        // stop if failed
        String mText = mqrcText.getMQRCText(mqe.Reason);     // get the message text
        System.Console.WriteLine( "create of MQQueueManager ended with " + mqe.Message + " Text: " + mText );
        return;
      }

      ///
      /// Try to open the queue
      ///
      try 
      {
        mqQueue = mqQMgr.AccessQueue( queueName, 
                                    MQC.MQOO_INPUT_AS_Q_DEF           // open queue for input
                                  + MQC.MQOO_FAIL_IF_QUIESCING );     // but not if MQM stopping
      }
      catch (MQException mqe) 
      {
        // stop if failed
        String mText = mqrcText.getMQRCText(mqe.Reason);      // get the message text
        System.Console.WriteLine( "MQQueueManager.AccessQueue ended with " + mqe.Message + " Text: " + mText );
        return;
      }

      ///
      /// Get messages from the message queue
      /// Loop until there is a failure
      /// 
      bool isContinue = true;
      while (isContinue) 
      {

        mqMsg = new MQMessage();
        mqGetMsgOpts = new MQGetMessageOptions();
        mqGetMsgOpts.WaitInterval = 15000;  // 15 second limit for waiting
        try 
        {
          mqQueue.Get( mqMsg, mqGetMsgOpts );
          if (mqMsg.Format.CompareTo(MQC.MQFMT_STRING) == 0) 
          {
            System.Console.WriteLine(  mqMsg.ReadString(mqMsg.MessageLength) );
          }
          else 
          {
            System.Console.WriteLine( "Non-text message" );
          }
        }
        catch (MQException mqe) 
        {
          // report reason, if any
          String mText = mqrcText.getMQRCText(mqe.Reason);
          if ( mText.Equals("MQRC_NO_MSG_AVAILABLE"))
          {
            // special report for normal end
            System.Console.WriteLine( "no more messages on queue LEXQ1" );
            isContinue = false;
          } 
          else 
          {
            // general report for other reasons
            System.Console.WriteLine( "MQQueue.Get ended with " + mqe.Message + " Text: " + mText );
            isContinue = false;
          }
        }
      }

      System.Console.WriteLine( "Example exmqget1 end" );
      return;
    }
  }
}
