//      program name:  exmqput1 - example of MQPUT to write a message to a queue
//                
//                exmqput1 has 2 parameters:
//                - the name of a queue (required)
//                - the name of a queue manager (required)
//
//    example command line:   exmqput1 LEXQ1 EXQMAN

using System;
using IBM.WMQ;

namespace exmqput1
{
  /// <summary>
  /// Summary description for exmqput1.
  /// </summary>
  class exmqput1
  {
    /// <summary>
    /// The main entry point for the application.
    /// </summary>
    [STAThread]
    static void Main(String[] args)
    {
      MQQueueManager      mqQMgr;          // MQQueueManager instance
      MQQueue             mqQueue;         // MQQueue instance
      MQMessage           mqMsg;           // MQMessage instance
      MQPutMessageOptions mqPutMsgOpts;    // MQPutMessageOptions instance
      MQRCText            mqrcText;        // MQRCText instance
      String              queueName;       // Name of queue to use
      int                 msgLen;          // Message length
      String              message;         // Message buffer

      System.Console.WriteLine( "Example exmqput1 start" );
      if (args.Length == 0) 
      {
        System.Console.WriteLine("Required parameters missing - 'queue name' 'queue manager name'" );
        return;
      }
      else 
      {
        queueName = args[0];
      }

      ///
      /// create an MQRCText instance
      /// 
       
      mqrcText = new MQRCText();
       
      ///
      /// Try to create an MQQueueManager instance 
      /// 
      try 
      {
        if (args.Length > 1)
        {
          // queue name, queue manager name provided
          mqQMgr = new MQQueueManager( args[1] );
          System.Console.WriteLine( "MQQueueManager: " + mqQMgr );
        }
        else 
        {
          if (args[0] == "?")
          {
           System.Console.WriteLine("execute exmqput1 as follows: exmqput1 'queue name' 'queue manager name'" );
           System.Console.WriteLine("                         eg. exmqput1 LEXQ1 EXQMAN " );
           return;
          }
          else
          {
            System.Console.WriteLine("Required parameter missing - queue manager name" );
            return;
          }
        }
      }
      catch (MQException mqe) 
      {
        // stop if failed
        String mText = mqrcText.getMQRCText(mqe.Reason);     // get the message text
        System.Console.WriteLine( "create of MQQueueManager ended with " + mqe.Message + " Text: " + mText );
        return;
      }

      ///
      /// Try to open the queue
      ///
      try 
      {
        mqQueue = mqQMgr.AccessQueue( queueName, 
                                    MQC.MQOO_OUTPUT                   // open queue for output
                                  + MQC.MQOO_FAIL_IF_QUIESCING );     // but not if MQM stopping
      }
      catch (MQException mqe) 
      {
        // stop if failed
        String mText = mqrcText.getMQRCText(mqe.Reason);      // get the message text
        System.Console.WriteLine( "MQQueueManager.AccessQueue ended with " + mqe.Message + " Text: " + mText );
        return;
      }

      ///
      /// Read lines from the console and put them to the message queue
      /// Loop until end of input, or there is a failure
      /// 
      bool isContinue = true;
      while (isContinue) 
      {
        System.Console.WriteLine( "Enter message..." );
        message = System.Console.ReadLine();
        msgLen = message.Length;

        if (msgLen > 0) 
        {
          // put the next message to the queue
          mqMsg = new MQMessage();
          mqMsg.WriteString( message );
          mqMsg.Format = MQC.MQFMT_STRING;
          mqPutMsgOpts = new MQPutMessageOptions();
          try
          {
            mqQueue.Put( mqMsg, mqPutMsgOpts );
          }
          catch (MQException mqe)
          {
            // report the error
            String mText = mqrcText.getMQRCText(mqe.Reason);
            System.Console.WriteLine( "MQQueue.Put ended with " + mqe.Message + " Text: " + mText );
          }
        }
        else 
        {
          // quit loop when empty line is read
          isContinue = false;
        }
      }

      System.Console.WriteLine( "Example exmqput1 end" );
      return;
    }
  }
}
